#!/bin/sh
# the next line restarts using wish \
exec wish "$0" "$@"

# Frontend for cd2tex  Thomas Klein  10/07

proc enable {output} {
 if {$output<3} {
  .ltex configure -state normal ; .etex configure -state normal
  .btex configure -state normal
  .lviewer configure -state disable ; .eviewer configure -state disable
 } else {
  .ltex  configure -state disable ; .etex configure -state disable;
  .btex configure -state disable 
  if {$output==3} {
   .lviewer configure -state disable ; .eviewer configure -state disable
  } else {
   .lviewer configure -state normal ; .eviewer configure -state normal
  }   
 }
}

proc latex {output} {
 global path dir tex title left right fsize depth mp3 size rotate viewer
 if {$dir!="" && ($tex !="" || $output>2)} {
  cd $path
  if {$output==1} {
   exec cd2tex $dir $title $left $right $fsize $depth $mp3 $size $rotate >$tex
  } else {
   exec cd2tex $dir $title $left $right $fsize $depth $mp3 $size $rotate >/tmp/cd2tex[pid].tex
   cd /tmp
   catch { exec xterm -e latex cd2tex[pid].tex }
   catch { exec dvips cd2tex[pid] }
   switch $output {
    2 { catch { exec rm cd2tex[pid].aux cd2tex[pid].log cd2tex[pid].tex cd2tex[pid].dvi }
        cd $path
        exec mv /tmp/cd2tex[pid].ps $tex
      }
    3 { catch { exec lpr cd2tex[pid].ps }
        catch { exec rm cd2tex[pid].aux cd2tex[pid].log cd2tex[pid].tex cd2tex[pid].dvi cd2tex[pid].ps }
      }
    4 { catch { exec $viewer cd2tex[pid].ps }
        catch { exec rm cd2tex[pid].aux cd2tex[pid].log cd2tex[pid].tex cd2tex[pid].dvi cd2tex[pid].ps }
      }
   }
  }
  cd $path
 }
}

set path [pwd]

frame .fleft1
frame .fleft2
frame .fright1
frame .fright2

label .ldir -text "Mountpoint:"
entry .edir -textvariable dir
button .bdir -text "Choose Dir" -command { set dir [tk_chooseDirectory] }
if {$argc>0} {set dir [lindex $argv 0]}

label .ltex -text "Output-File:"
entry .etex -textvariable tex
button .btex -text "Choose File" -command { set tex [tk_getSaveFile] }
if {$argc>1} {set tex [lindex $argv 1]}

label .lleft -text "Left Text:"
entry .eleft -textvariable left
if {$argc>3} {set left [lindex $argv 3]}

label .lright -text "Right Text:"
entry .eright -textvariable right
if {$argc>4} {set right [lindex $argv 4]}

label .ltitle -text "Disc-Title:"
entry .etitle -textvariable title
if {$argc>2} {set title [lindex $argv 2]}

label .ldepth -text "Recursion Depth:"
spinbox .sdepth -from 0 -to 255 -textvariable depth
set depth 10

label .lfsize -text "Font-Size:"
scale .sfsize -from 1 -to 8 -tickinterval 2 -orient h -variable fsize
set fsize 3

label .lsize -text "Title-Size:\n(0: Front-Cover)"
scale .ssize -from 0 -to 8 -tickinterval 2 -orient h -variable size
set size 6

checkbutton .crotate -text "Rotate Title" -variable rotate
set rotate 1

label .loutput -text "Output-Format:"
radiobutton .rtex -text "TEX" -variable output -value 1 -width 5 -anchor w -command { enable 1 }
radiobutton .rps -text "PS" -variable output -value 2 -width 5 -anchor w -command { enable 2 }
radiobutton .rlpr -text "Print" -variable output -value 3 -width 5 -anchor w -command { enable 3 }
radiobutton .rview -text "View" -variable output -value 4 -width 5 -anchor w -command { enable 4 }
set output 1

label .lviewer -text "Viewer:"
entry .eviewer -textvariable viewer
set viewer "gv"

checkbutton .cmp3 -text "MP3" -variable mp3
set mp3 0

button .brun -text "Run" -width 4 -command { latex $output }

button .bquit -text "Quit" -width 4 -command { cd $path ; exit }

enable $output

pack .ldir .edir .bdir .lleft .eleft .ltitle .etitle -in .fleft1
pack .ltex .etex .btex .lright .eright .ldepth .sdepth -in .fright1
pack .lfsize .sfsize .lsize .ssize -in .fleft2
pack .loutput .rtex .rps .rlpr .rview .lviewer .eviewer -in .fright2

grid .fleft1 -row 0 -column 0
grid .fright1 -row 0 -column 1
grid .fleft2 -row 1 -column 0
grid .fright2 -row 1 -column 1
grid .crotate -row 2 -column 0
grid .cmp3 -row 2 -column 1
grid .brun -row 3 -column 0
grid .bquit -row 3 -column 1
