#!/bin/sh
# the next line restarts using wish \
exec wish "$0" "$@"

# Frontend for cddb2tex  Thomas Klein  10/07

proc enable {output} {
 if {$output<3} {
  .ltex configure -state normal ; .etex configure -state normal
  .btex configure -state normal
  .lviewer configure -state disable ; .eviewer configure -state disable
 } else {
  .ltex  configure -state disable ; .etex configure -state disable;
  .btex configure -state disable 
  if {$output==3} {
   .lviewer configure -state disable ; .eviewer configure -state disable
  } else {
   .lviewer configure -state normal ; .eviewer configure -state normal
  }   
 }
}

proc latex {output} {
 global path cddb tex left right size rotate viewer
 if {$cddb!="" && ($tex !="" || $output>2)} {
  cd $path
  if {$output==1} {
   exec cddb2tex $cddb $left $right $size $rotate >$tex
  } else {
   exec cddb2tex $cddb $left $right $size $rotate >/tmp/cddb2tex[pid].tex
   cd /tmp
   catch { exec xterm -e latex cddb2tex[pid].tex }
   catch { exec dvips cddb2tex[pid] }
   switch $output {
    2 { catch { exec rm cddb2tex[pid].aux cddb2tex[pid].log cddb2tex[pid].tex cddb2tex[pid].dvi }
        cd $path
        exec mv /tmp/cddb2tex[pid].ps $tex
      }
    3 { catch { exec lpr cddb2tex[pid].ps }
        catch { exec rm cddb2tex[pid].aux cddb2tex[pid].log cddb2tex[pid].tex cddb2tex[pid].dvi cddb2tex[pid].ps }
      }
    4 { catch { exec $viewer cddb2tex[pid].ps }
        catch { exec rm cddb2tex[pid].aux cddb2tex[pid].log cddb2tex[pid].tex cddb2tex[pid].dvi cddb2tex[pid].ps }
      }
   }
  }
  cd $path
 }
}

set path [pwd]

frame .fleft1
frame .fleft2
frame .fright1
frame .fright2

label .lcddb -text "CDDB-File:"
entry .ecddb -textvariable cddb
button .bcddb -text "Choose File" -command { set cddb [tk_getOpenFile] }
if {$argc>0} {set cddb [lindex $argv 0]}

label .ltex -text "Output-File:"
entry .etex -textvariable tex
button .btex -text "Choose File" -command { set tex [tk_getSaveFile] }
if {$argc>1} {set tex [lindex $argv 1]}

label .lleft -text "Left Text:"
entry .eleft -textvariable left
if {$argc>2} {set left [lindex $argv 2]}

label .lright -text "Right Text:"
entry .eright -textvariable right
if {$argc>3} {set right [lindex $argv 3]}

label .lsize -text "Title-Size:\n(0: Front-Cover)"
scale .ssize -from 0 -to 8 -tickinterval 2 -orient h -variable size
set size 6

checkbutton .crotate -text "Rotate Title" -variable rotate
set rotate 1

label .loutput -text "Output-Format:"
radiobutton .rtex -text "TEX" -variable output -value 1 -width 5 -anchor w -command { enable 1 }
radiobutton .rps -text "PS" -variable output -value 2 -width 5 -anchor w -command { enable 2 }
radiobutton .rlpr -text "Print" -variable output -value 3 -width 5 -anchor w -command { enable 3 }
radiobutton .rview -text "View" -variable output -value 4 -width 5 -anchor w -command { enable 4 }
set output 1

label .lviewer -text "Viewer:"
entry .eviewer -textvariable viewer
set viewer "gv"

button .brun -text "Run" -width 4 -command { latex $output }

button .bquit -text "Quit" -width 4 -command { cd $path ; exit }

enable $output

pack .lcddb .ecddb .bcddb .lleft .eleft -in .fleft1
pack .ltex .etex .btex .lright .eright -in .fright1
pack .lsize .ssize .crotate -in .fleft2
pack .loutput .rtex .rps .rlpr .rview .lviewer .eviewer -in .fright2

grid .fleft1 -row 0 -column 0
grid .fright1 -row 0 -column 1
grid .fleft2 -row 1 -column 0
grid .fright2 -row 1 -column 1
grid .brun -row 2 -column 0
grid .bquit -row 2 -column 1
